@@ -6,6 +6,11 @@ Author: Zachary Ashen
 Date: June 3rd 2020
 """
 
+import re
+from textwrap import fill
+
+import gkeepapi
+
 
 def listifyGoogleNotes(googleNotes):
     """Returns: a nested list from a Google Note object. Checked items are removed from the list.
